@@ -1723,7 +1723,7 @@ public:
          * @param number of encoded bytes to record.
          * @return number of encoded bytes recorded.
          */
-	virtual ssize_t getBuffer(Encoded data, unsigned len);
+	virtual ssize_t getBuffer(Encoded data, size_t len);
 
 	/**
 	 * Use encoding source descriptor to select the audio encoding
