@@ -138,9 +138,9 @@ unsigned long AudioFile::getLong(unsigned char * data)
 	return val;
 }
 
-AudioFile::AudioFile(const char *name, unsigned long sample)
+AudioFile::AudioFile(const char *name, unsigned long sample) :
+AudioBase()
 {
-	memset(&this->info, 0, sizeof(this->info));
 	pathname = NULL;
 	initialize();
 	AudioFile::open(name);
@@ -149,12 +149,12 @@ AudioFile::AudioFile(const char *name, unsigned long sample)
 	setPosition(sample);
 }
 
-AudioFile::AudioFile(const char *name, Info *info, unsigned long samples)
+AudioFile::AudioFile(const char *name, Info *inf, unsigned long samples) :
+AudioBase(inf)
 {
-	memset(&this->info, 0, sizeof(this->info));
 	pathname = NULL;
 	initialize();
-	AudioFile::create(name, info);
+	AudioFile::create(name, inf);
 	if(!isOpen())
 		return;
 	setMinimum(samples);
@@ -1058,7 +1058,7 @@ unsigned AudioFile::getLinear(Linear addr, unsigned samples)
 
 	if(getEncoding() == pcm16Mono)
 	{
-		count = getBuffer(addr, samples * 2);
+		count = getBuffer((Encoded)addr, samples * 2);
 		if(count < 0)
 			return 0;
 		return count / 2;
@@ -1072,7 +1072,7 @@ unsigned AudioFile::getLinear(Linear addr, unsigned samples)
 	samples = (samples / count) * count;
 	count = (int)toBytes(info, samples);
 
-	char *buffer = new char[count];
+	Encoded buffer = new unsigned char[count];
 	count = getBuffer(buffer, count);
 	if(count < 1)
 	{
@@ -1096,7 +1096,7 @@ unsigned AudioFile::putLinear(Linear addr, unsigned samples)
 
 	if(getEncoding() == pcm16Mono)
 	{
-		count = putBuffer(addr, samples * 2);
+		count = putBuffer((Encoded)addr, samples * 2);
 		if(count < 0)
 			return 0;
 		return count / 2;
@@ -1109,7 +1109,7 @@ unsigned AudioFile::putLinear(Linear addr, unsigned samples)
 	samples = samples / count * count;
 	count = (int)toBytes(info, samples);
 
-	char *buffer = new char[count];
+	Encoded buffer = new unsigned char[count];
 
 	samples = codec->encode(addr, buffer, samples);
 	if(samples < 1)
@@ -1126,11 +1126,10 @@ unsigned AudioFile::putLinear(Linear addr, unsigned samples)
 }
 
 
-int AudioFile::getBuffer(void *addr, unsigned bytes)
+ssize_t AudioFile::getBuffer(Encoded addr, size_t bytes)
 {
 	Info prior;
 	char *fname;
-	unsigned char *caddr = (unsigned char *)addr;
 	int count;
 	unsigned long curpos, xfer = 0;
 
@@ -1152,7 +1151,7 @@ int AudioFile::getBuffer(void *addr, unsigned bytes)
 
 	for(;;)
 	{
-		count = afRead(caddr, bytes);
+		count = afRead(addr, (unsigned)bytes);
 		if(count < 0)
 		{
 			if(!xfer)
@@ -1192,7 +1191,7 @@ retry:
 		}
 cont:
 		bytes -= count;
-		caddr += count;
+		addr += count;
 	}
 }
 
@@ -1257,7 +1256,7 @@ retry:
 	return errReadIncomplete;
 }
 
-int AudioFile::putBuffer(void *addr, unsigned len)
+ssize_t AudioFile::putBuffer(Encoded addr, size_t len)
 {
 	int count;
 	unsigned long curpos;
@@ -1278,7 +1277,7 @@ int AudioFile::putBuffer(void *addr, unsigned len)
         if (len <= 0)
 		return 0;  
 
-	count = afWrite((unsigned char *)addr, len);
+	count = afWrite((unsigned char *)addr, (unsigned)len);
 	if(count == (int)len) {
 		length += count;
 		return count;
