@@ -103,7 +103,7 @@ AudioRegistry::AudioRegistry()
 	HKEY key;
 	char *env;
 
-	codecdir = "C:/Program Files/Common Files/CAPE Framework/Audio Codecs";
+	codecdir = "C:/Program Files/Common Files/GNU Telephony/Audio Codecs";
 
 #ifdef	DEBUG
 #define	PLUGINS "Debug"
